@@ -6,7 +6,7 @@ use parent 'Exporter';
 use Text::Trim qw(trim rtrim);
 use XSLoader;
 
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 XSLoader::load( __PACKAGE__, $VERSION );
 
 our @EXPORT_OK = qw[];
@@ -107,7 +107,7 @@ JavaScript::V8::XS - Perl XS binding for the V8 Javascript embeddable engine
 
 =head1 VERSION
 
-Version 0.000003
+Version 0.000004
 
 =head1 SYNOPSIS
 
@@ -145,6 +145,8 @@ Version 0.000003
     my $msgs_href = $vm->get_msgs();
     $vm->reset_msgs();
 
+    my $globals = $vm->global_objects();
+
     my $context = $vm->parse_js_stacktrace($stacktrace_lines, 2);
 
     my $rounds = $vm->run_gc();
@@ -156,6 +158,29 @@ This module provides an XS wrapper to call V8 from Perl.
 The wrapper is used in an OO way: you create an instance of
 C<JavaScript::V8::XS> and then invoke functions on it.
 
+=head1 DEPENDENCIES
+
+This module requires that recent versions of the V8 and ICU libraries have
+already been installed in your system.
+
+At the time of writing, versions used were V8 6.7 and ICU 61.
+
+The module does not attempt to download / install these required external
+dependencies:
+
+=over 4
+
+=item * header files
+
+=item * shared libraries
+
+=item * V8 blobs, usually generated at compilation time (C<natives_blob.bin>
+and C<snapshot_blob.bin>)
+
+=item * ICU data files (C<icudtl.dat>)
+
+=back
+
 =head1 METHODS/ATTRIBUTES
 
 =head2 new
@@ -255,6 +280,10 @@ object with option C<save_messages> set to true.
 
 Reset the accumulated messages, as if the XS object had just been created.
 
+=head2 global_objects
+
+Get an arrayref with the names of all global objects known to JavaScript.
+
 =head2 parse_js_stacktrace
 
 Parse a JavaScript stacktrace (usually returned via C<get_msgs>) and obtain
@@ -273,8 +302,13 @@ number of rounds that were effectively run.
 
 =head1 SEE ALSO
 
-L<< https://metacpan.org/pod/JavaScript::V8 >>
-L<< https://metacpan.org/pod/JavaScript::Duktape::XS >>
+=over 4
+
+=item * L<< https://metacpan.org/pod/JavaScript::V8 >>
+
+=item * L<< https://metacpan.org/pod/JavaScript::Duktape::XS >>
+
+=back
 
 =head1 LICENSE
 
