@@ -318,7 +318,7 @@ SV* pl_get_global_or_property(pTHX_ V8Context* ctx, const char* name)
     SV* ret = &PL_sv_undef; /* return undef by default */
 
     HandleScope handle_scope(ctx->isolate);
-    Local<Context> context = Local<Context>::New(ctx->isolate, ctx->persistent_context);
+    Local<Context> context = Local<Context>::New(ctx->isolate, *ctx->persistent_context);
     Context::Scope context_scope(context);
 
     Local<Object> object;
@@ -335,7 +335,7 @@ int pl_set_global_or_property(pTHX_ V8Context* ctx, const char* name, SV* value)
     int ret = 0;
 
     HandleScope handle_scope(ctx->isolate);
-    Local<Context> context = Local<Context>::New(ctx->isolate, ctx->persistent_context);
+    Local<Context> context = Local<Context>::New(ctx->isolate, *ctx->persistent_context);
     Context::Scope context_scope(context);
 
     Local<Object> parent;
@@ -355,7 +355,7 @@ SV* pl_exists_global_or_property(pTHX_ V8Context* ctx, const char* name)
     SV* ret = &PL_sv_no; /* return false by default */
 
     HandleScope handle_scope(ctx->isolate);
-    Local<Context> context = Local<Context>::New(ctx->isolate, ctx->persistent_context);
+    Local<Context> context = Local<Context>::New(ctx->isolate, *ctx->persistent_context);
     Context::Scope context_scope(context);
 
     Local<Object> object;
@@ -372,7 +372,7 @@ SV* pl_typeof_global_or_property(pTHX_ V8Context* ctx, const char* name)
     const char* cstr = "undefined";
 
     HandleScope handle_scope(ctx->isolate);
-    Local<Context> context = Local<Context>::New(ctx->isolate, ctx->persistent_context);
+    Local<Context> context = Local<Context>::New(ctx->isolate, *ctx->persistent_context);
     Context::Scope context_scope(context);
 
     Local<Object> object;
@@ -391,7 +391,7 @@ SV* pl_instanceof_global_or_property(pTHX_ V8Context* ctx, const char* oname, co
     SV* ret = &PL_sv_no; /* return false by default */
 
     HandleScope handle_scope(ctx->isolate);
-    Local<Context> context = Local<Context>::New(ctx->isolate, ctx->persistent_context);
+    Local<Context> context = Local<Context>::New(ctx->isolate, *ctx->persistent_context);
     Context::Scope context_scope(context);
 
     Local<Object> oobject;
@@ -410,6 +410,28 @@ SV* pl_instanceof_global_or_property(pTHX_ V8Context* ctx, const char* oname, co
     return ret;
 }
 
+SV* pl_global_objects(pTHX_ V8Context* ctx)
+{
+    HandleScope handle_scope(ctx->isolate);
+    Local<Context> context = Local<Context>::New(ctx->isolate, *ctx->persistent_context);
+    Context::Scope context_scope(context);
+
+    Local<Object> global = context->Global();
+    Local<Array> property_names = global->GetOwnPropertyNames();
+    int count = 0;
+    AV* values = newAV();
+    for (uint32_t j = 0; j < property_names->Length(); ++j) {
+        Local<Value> v8_key = property_names->Get(j);
+        // TODO: check we got a valid key
+        String::Utf8Value key(ctx->isolate, v8_key->ToString());
+        SV* name = sv_2mortal(newSVpvn(*key, key.length()));
+        if (av_store(values, count, name)) {
+            SvREFCNT_inc(name);
+            ++count;
+        }
+    }
+    return newRV((SV*) values);
+}
 int pl_run_gc(V8Context* ctx)
 {
     // Run PL_GC_RUNS GC rounds
